@@ -352,7 +352,8 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
                     weight_feature_effect = weight_shap_values.sum(axis=1)
                     weight_actual_predictions_from_shapley_values = weight_expected_values + weight_feature_effect
                     if np.sum(np.abs(weight_actual_predictions - weight_actual_predictions_from_shapley_values)) > 1e-6:
-                        raise Exception('Mismatch between shapley values and actual predictions')
+                        #raise Exception('Mismatch between shapley values and actual predictions')
+                        print('Mismatch between shapley values and actual predictions')
 
         predictors_shap_values = [list_average(shap_values)]
         predictors_feature_order = np.argsort(np.sum(np.mean(np.abs(predictors_shap_values), axis=0), axis=0))
@@ -455,10 +456,12 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
             test_prediction = self.sub_predict(self.X[test_slice])
             self.y_test[test_slice] = test_prediction
             ### features computation
+            me_pred = torch.cat((eval_prediction, test_prediction), 0)
+            me_features = torch.cat((self.X[eval_slice], self.X[test_slice]), 0)
             if gradient :
-                features_dico = self.gradient_eval_predictor_importance(self.X[test_slice], test_prediction, feature_names)
+                features_dico = self.gradient_eval_predictor_importance(me_features, me_pred, feature_names)
             else:
-                features_dico = self.eval_predictor_importance(self.X[test_slice], test_prediction, feature_names)
+                features_dico = self.eval_predictor_importance(me_features, me_pred, feature_names)
             rows_list.append(features_dico)
             dates_list.append(dates[test_slice.start])
 
