@@ -98,6 +98,8 @@ class EnsemblingSignalRunner(AbstractRunner):
             run_json_string = signal_utility.recover_to_sql_column_format(me_signal)
             params = json.loads(run_json_string)
             signal_type = params['signal_type']
+            if normalization and signal_generator.is_signal_continuum(signal_type):
+                return
             print('Launching computation with parameters : '+run_json_string)
             if signal_type == 'long_only':
                 hourly_df['signal']=1.
