@@ -3,9 +3,10 @@
 
 import numpy as np
 import numpy.ma as ma
-
 from napoleontoolbox.tools.analyze_tools import roll_corr
-#comment
+
+continuum_signals = ['alpha_2', 'alpha_3', 'alpha5',  'alpha_6', 'alpha_6_rank', 'alpha_8', 'alpha_12', 'alpha_13', 'alpha_14',  'alpha_15',  'alpha_16', 'slope_induced' ]
+
 def compute_correlation(col_one, col_two):
     a = ma.masked_invalid(col_one)
     b = ma.masked_invalid(col_two)
@@ -14,7 +15,10 @@ def compute_correlation(col_one, col_two):
     correlation_coefficient = correlation_matrix[0][1]
     return correlation_coefficient
 
-# zura kakushade alphas
+def is_signal_continuum(signal_type):
+    if signal_type in continuum_signals:
+        return True
+
 def alpha_2(data = None,  contravariant = -1., **kwargs):
     data['log_vol'] = np.log(data['volumefrom'])
     correlation_coefficient = compute_correlation(data.log_vol.diff(2).rank(pct=True), (data.close - data.open)/data.open)
