@@ -70,20 +70,24 @@ def f_sharpe_signals_mix(data, w):
     temp_df = temp_df.rename(columns={"signal0": "signal"}, errors="raise")
     tt = pd.DataFrame(data[all_signals].values * w, columns=all_signals, index=data.index)
     temp_df['signal'] = tt.sum(axis=1)
-    hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, print_turnover=True)
+    hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, print_turnover=False)
     sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
     return -sharpe_strat
 
-def expanding_zscore(signal_np_array=None, skipping_point = 5):
-    me_zscore_expanding_array = np.zeros(signal_np_array.shape)
-    for i in range(len(signal_np_array)):
-        if i <= skipping_point:
-            me_zscore_expanding_array[i] = signal_np_array[i]
-        else :
-            std_dev = max(signal_np_array[:i].std(), 1e-6)
-            me_zscore_expanding_array[i] = (signal_np_array[i] - signal_np_array[:i].mean())/std_dev
-    return me_zscore_expanding_array
-
+def expanding_zscore(signal_np_array=None, skipping_point = 5, signal_continuum_threshold = 20):
+    signal_np_array
+    u = np.unique(signal_np_array)
+    if len(u) >= signal_continuum_threshold:
+        me_zscore_expanding_array = np.zeros(signal_np_array.shape)
+        for i in range(len(signal_np_array)):
+            if i <= skipping_point:
+                me_zscore_expanding_array[i] = signal_np_array[i]
+            else :
+                std_dev = max(signal_np_array[:i].std(), 1e-6)
+                me_zscore_expanding_array[i] = (signal_np_array[i] - signal_np_array[:i].mean())/std_dev
+        return me_zscore_expanding_array
+    else:
+        raise Exception('zscoring a non continuous signal')
 
 def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False):
     if normalization:
@@ -151,17 +155,9 @@ def compute_signals_weights_perf(data = None, optimal_weights = None, starting_d
     optimal_signal = pd.DataFrame(data[all_sigs].values * optimal_weights, columns=all_sigs, index=data.index)
     temp_df['signal'] = optimal_signal.sum(axis=1)
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=False, normalization=normalization)
-    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    sharpe_strat_without = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
     sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=252 * 24, from_ret=True)
-    print('underlying sharpe')
-    print(sharpe_under)
-    print('strat sharpe without transaction costs')
-    print(sharpe_strat)
+
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, normalization=normalization)
     sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
-    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=252 * 24, from_ret=True)
-    print('underlying sharpe')
-    print(sharpe_under)
-    print('strat sharpe with transaction costs')
-    print(sharpe_strat)
-    return sharpe_strat
\ No newline at end of file
+    return hourly_df, sharpe_strat, sharpe_strat_without, sharpe_under
\ No newline at end of file
